@@ -203,7 +203,7 @@ def refresh_access_token(ctx: JobbergateContext, token_set: TokenSet):
 
     If refresh fails, notify the user that they need to log in again.
     """
-    url = f"https://{settings.OIDC_DOMAIN}/token"
+    url = f"https://{settings.OIDC_DOMAIN}/protocol/openid-connect/token"
     logger.debug(f"Requesting refreshed access token from {url}")
 
     JobbergateCliError.require_condition(
@@ -219,7 +219,7 @@ def refresh_access_token(ctx: JobbergateContext, token_set: TokenSet):
         make_request(
             # Can this even work? this client should be for the armada api...
             ctx.client,
-            "/token",
+            "/protocol/openid-connect/token",
             "POST",
             abort_message="The auth token could not be refreshed. Please try logging in again.",
             abort_subject="EXPIRED ACCESS TOKEN",
@@ -251,7 +251,7 @@ def fetch_auth_tokens(ctx: JobbergateContext) -> TokenSet:
         DeviceCodeData,
         make_request(
             ctx.client,
-            "/auth/device",
+            "/protocol/openid-connect/auth/device",
             "POST",
             expected_status=200,
             abort_message="There was a problem retrieving a device verification code from the auth provider",
@@ -286,7 +286,7 @@ def fetch_auth_tokens(ctx: JobbergateContext) -> TokenSet:
             Dict,
             make_request(
                 ctx.client,
-                "/token",
+                "/protocol/openid-connect/token",
                 "POST",
                 abort_message="There was a problem retrieving a device verification code from the auth provider",
                 abort_subject="COULD NOT FETCH ACCESS TOKEN",
