@@ -3,6 +3,7 @@ Provide a ``typer`` app that can interact with Job Submission data in a cruddy m
 """
 
 from pathlib import Path
+from textwrap import dedent
 from typing import Any, Dict, Optional, cast
 
 import typer
@@ -12,6 +13,7 @@ from jobbergate_cli.exceptions import handle_abort
 from jobbergate_cli.render import StyleMapper, render_list_results, render_single_result, terminal_message
 from jobbergate_cli.requests import make_request
 from jobbergate_cli.schemas import JobbergateContext, ListResponseEnvelope
+from jobbergate_cli.subapps.job_scripts.tools import download_job_script_files
 from jobbergate_cli.subapps.job_submissions.tools import create_job_submission, fetch_job_submission_data
 
 
@@ -19,6 +21,7 @@ from jobbergate_cli.subapps.job_submissions.tools import create_job_submission,
 HIDDEN_FIELDS = [
     "created_at",
     "updated_at",
+    "execution_parameters",
 ]
 
 
@@ -50,12 +53,30 @@ def create(
     ),
     execution_directory: Optional[Path] = typer.Option(
         None,
-        help="""
+        help=dedent(
+            """
             The path on the cluster where the job script should be executed.
             If provided as a relative path, it will be converted as an absolute path from your current
-            working directory. If you use "~" to denote your home directory, the path will be expanded to an absolute
-            path for your home directory on *this* machine.
-        """,
+            working directory. If you use "~" to denote your home directory, the path will be expanded to an
+            absolute path for your home directory on *this* machine.
+            """
+        ).strip(),
+    ),
+    execution_parameters: Optional[Path] = typer.Option(
+        None,
+        help=dedent(
+            """
+            The path to a JSON file containing the parameters to be passed to the job submission.
+            See more details at: https://slurm.schedmd.com/rest_api.html
+            """
+        ).strip(),
+        exists=True,
+        readable=True,
+        resolve_path=True,
+    ),
+    download: bool = typer.Option(
+        False,
+        help="Download the job script files to the current working directory",
     ),
 ):
     """
@@ -73,7 +94,12 @@ def create(
         description=description,
         execution_directory=execution_directory,
         cluster_name=cluster_name,
+        execution_parameters_file=execution_parameters,
     )
+
+    if download:
+        download_job_script_files(job_script_id, jg_ctx)
+
     render_single_result(
         jg_ctx,
         result,
@@ -86,13 +112,21 @@ def create(
 @handle_abort
 def list_all(
     ctx: typer.Context,
-    show_all: bool = typer.Option(False, "--all", help="Show all job submissions, even the ones owned by others"),
+    show_all: bool = typer.Option(
+        False,
+        "--all",
+        help="Show all job submissions, even the ones owned by others",
+    ),
     search: Optional[str] = typer.Option(None, help="Apply a search term to results"),
     sort_order: SortOrder = typer.Option(SortOrder.UNSORTED, help="Specify sort order"),
     sort_field: Optional[str] = typer.Option(None, help="The field by which results should be sorted"),
+    from_job_script_id: Optional[int] = typer.Option(
+        None,
+        help="Filter job-submissions by the job-script-id they were created from.",
+    ),
 ):
     """
-    Show available job scripts
+    Show available job submissions.
     """
     jg_ctx: JobbergateContext = ctx.obj
 
@@ -107,6 +141,8 @@ def list_all(
         params["sort_ascending"] = SortOrder is SortOrder.ASCENDING
     if sort_field is not None:
         params["sort_field"] = sort_field
+    if from_job_script_id is not None:
+        params["from_job_script_id"] = from_job_script_id
 
     envelope = cast(
         ListResponseEnvelope,
